==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/AlignLinearGraphLabelEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatLinearGraphLabelEventArgsDescriptionMetadata } from "./FormatLinearGraphLabelEventArgsDescriptionMetadata";
import { AlignLinearGraphLabelEventArgsDescription } from "./AlignLinearGraphLabelEventArgsDescription";
/**
 * @hidden
 */
var AlignLinearGraphLabelEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AlignLinearGraphLabelEventArgsDescriptionMetadata, _super);
    function AlignLinearGraphLabelEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AlignLinearGraphLabelEventArgsDescriptionMetadata.b = function (a) {
        if (AlignLinearGraphLabelEventArgsDescriptionMetadata.a == null) {
            AlignLinearGraphLabelEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AlignLinearGraphLabelEventArgsDescriptionMetadata.c(AlignLinearGraphLabelEventArgsDescriptionMetadata.a);
        }
        if (a.g(AlignLinearGraphLabelEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(AlignLinearGraphLabelEventArgsDescriptionMetadata.a);
    };
    AlignLinearGraphLabelEventArgsDescriptionMetadata.c = function (a) {
        FormatLinearGraphLabelEventArgsDescriptionMetadata.c(a);
    };
    AlignLinearGraphLabelEventArgsDescriptionMetadata.d = function (a) {
        AlignLinearGraphLabelEventArgsDescriptionMetadata.b(a);
        a.u("AlignLinearGraphLabelEventArgs", function () { return new AlignLinearGraphLabelEventArgsDescription(); });
        a.t("AlignLinearGraphLabelEventArgs", AlignLinearGraphLabelEventArgsDescriptionMetadata.a);
    };
    AlignLinearGraphLabelEventArgsDescriptionMetadata.$t = markType(AlignLinearGraphLabelEventArgsDescriptionMetadata, 'AlignLinearGraphLabelEventArgsDescriptionMetadata');
    AlignLinearGraphLabelEventArgsDescriptionMetadata.a = null;
    return AlignLinearGraphLabelEventArgsDescriptionMetadata;
}(Base));
export { AlignLinearGraphLabelEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/AlignLinearGraphLabelEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatLinearGraphLabelEventArgsDescriptionMetadata } from "./FormatLinearGraphLabelEventArgsDescriptionMetadata";
import { AlignLinearGraphLabelEventArgsDescription } from "./AlignLinearGraphLabelEventArgsDescription";
/**
 * @hidden
 */
var AlignLinearGraphLabelEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AlignLinearGraphLabelEventArgsDescriptionMetadata, _super);
    function AlignLinearGraphLabelEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AlignLinearGraphLabelEventArgsDescriptionMetadata.b = function (a) {
        if (AlignLinearGraphLabelEventArgsDescriptionMetadata.a == null) {
            AlignLinearGraphLabelEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AlignLinearGraphLabelEventArgsDescriptionMetadata.c(AlignLinearGraphLabelEventArgsDescriptionMetadata.a);
        }
        if (a.j(AlignLinearGraphLabelEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(AlignLinearGraphLabelEventArgsDescriptionMetadata.a);
    };
    AlignLinearGraphLabelEventArgsDescriptionMetadata.c = function (a) {
        FormatLinearGraphLabelEventArgsDescriptionMetadata.c(a);
    };
    AlignLinearGraphLabelEventArgsDescriptionMetadata.d = function (a) {
        AlignLinearGraphLabelEventArgsDescriptionMetadata.b(a);
        a.aa("AlignLinearGraphLabelEventArgs", function () { return new AlignLinearGraphLabelEventArgsDescription(); });
        a.z("AlignLinearGraphLabelEventArgs", AlignLinearGraphLabelEventArgsDescriptionMetadata.a);
    };
    AlignLinearGraphLabelEventArgsDescriptionMetadata.$t = markType(AlignLinearGraphLabelEventArgsDescriptionMetadata, 'AlignLinearGraphLabelEventArgsDescriptionMetadata');
    AlignLinearGraphLabelEventArgsDescriptionMetadata.a = null;
    return AlignLinearGraphLabelEventArgsDescriptionMetadata;
}(Base));
export { AlignLinearGraphLabelEventArgsDescriptionMetadata };
